|
From: <caw...@us...> - 2007-02-28 14:13:22
|
Revision: 2063
http://svn.sourceforge.net/rubyeclipse/?rev=2063&view=rev
Author: cawilliams
Date: 2007-02-28 06:13:21 -0800 (Wed, 28 Feb 2007)
Log Message:
-----------
clean up type safety warnings
Modified Paths:
--------------
trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/LaunchingPlugin.java
trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/RubyVMRuntimeLoadpathEntryResolver.java
Modified: trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/LaunchingPlugin.java
===================================================================
--- trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/LaunchingPlugin.java 2007-02-28 14:10:11 UTC (rev 2062)
+++ trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/LaunchingPlugin.java 2007-02-28 14:13:21 UTC (rev 2063)
@@ -67,7 +67,7 @@
/**
* Runtime classpath extensions
*/
- private HashMap fClasspathEntryExtensions = null;
+ private HashMap<String, IConfigurationElement> fClasspathEntryExtensions = null;
/**
* Identifier for 'runtimeLoadpathEntries' extension point
@@ -79,7 +79,7 @@
* Mapping of top-level VM installation directories to library info for that
* VM.
*/
- private static Map fgLibraryInfoMap = null;
+ private static Map<String, LibraryInfo> fgLibraryInfoMap = null;
/**
* Whether changes in VM preferences are being batched. When being batched
@@ -227,9 +227,9 @@
// Generate the current
VMDefinitionsContainer newResults = getVMDefinitions(newPrefString);
- // Determine the deteled VMs
- List deleted = oldResults.getVMList();
- List current = newResults.getValidVMList();
+ // Determine the deleted VMs
+ List<IVMInstall> deleted = oldResults.getVMList();
+ List<IVMInstall> current = newResults.getValidVMList();
deleted.removeAll(current);
// Dispose deleted VMs. The 'disposeVMInstall' method fires notification of the
@@ -501,7 +501,7 @@
* Restores library information for VMs
*/
private static void restoreLibraryInfo() {
- fgLibraryInfoMap = new HashMap(10);
+ fgLibraryInfoMap = new HashMap<String, LibraryInfo>(10);
IPath libPath = getDefault().getStateLocation();
libPath = libPath.append("libraryInfos.xml"); //$NON-NLS-1$
File file = libPath.toFile();
@@ -545,7 +545,7 @@
}
private static String[] getPathsFromXML(Element lib, String pathType) {
- List paths = new ArrayList();
+ List<String> paths = new ArrayList<String>();
NodeList list = lib.getChildNodes();
int length = list.getLength();
for (int i = 0; i < length; ++i) {
@@ -601,7 +601,7 @@
private void initializeRuntimeLoadpathExtensions() {
IExtensionPoint extensionPoint= Platform.getExtensionRegistry().getExtensionPoint(LaunchingPlugin.PLUGIN_ID, ID_EXTENSION_POINT_RUNTIME_CLASSPATH_ENTRIES);
IConfigurationElement[] configs= extensionPoint.getConfigurationElements();
- fClasspathEntryExtensions = new HashMap(configs.length);
+ fClasspathEntryExtensions = new HashMap<String, IConfigurationElement>(configs.length);
for (int i= 0; i < configs.length; i++) {
fClasspathEntryExtensions.put(configs[i].getAttribute("id"), configs[i]); //$NON-NLS-1$
}
@@ -655,7 +655,7 @@
private boolean fDefaultChanged = false;
// old container ids to new
- private HashMap fRenamedContainerIds = new HashMap();
+ private HashMap<IPath, IPath> fRenamedContainerIds = new HashMap<IPath, IPath>();
/**
* Returns the JRE container id that the given VM would map to, or
Modified: trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/RubyVMRuntimeLoadpathEntryResolver.java
===================================================================
--- trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/RubyVMRuntimeLoadpathEntryResolver.java 2007-02-28 14:10:11 UTC (rev 2062)
+++ trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/RubyVMRuntimeLoadpathEntryResolver.java 2007-02-28 14:13:21 UTC (rev 2063)
@@ -90,10 +90,10 @@
if (vmInstallLocation != null) {
LibraryInfo libraryInfo= LaunchingPlugin.getLibraryInfo(vmInstallLocation.getAbsolutePath());
if (libraryInfo != null) {
// only return endorsed and bootstrap classpath entries if we have the info
// libs in the ext dirs are not loaded by the boot class loader
- List resolvedEntries = new ArrayList(libs.length);
+ List<IRuntimeLoadpathEntry> resolvedEntries = new ArrayList<IRuntimeLoadpathEntry>(libs.length);
for (int i = 0; i < libs.length; i++) {
IPath location = libs[i];
IPath libraryPath = location;
@@ -104,7 +104,7 @@
}
}
}
- List resolvedEntries = new ArrayList(libs.length);
+ List<IRuntimeLoadpathEntry> resolvedEntries = new ArrayList<IRuntimeLoadpathEntry>(libs.length);
for (int i = 0; i < libs.length; i++) {
IPath systemLibraryPath = libs[i];
if (systemLibraryPath.toFile().exists()) {
@@ -90,10 +90,10 @@
LibraryInfo libraryInfo= LaunchingPlugin.getLibraryInfo(vmInstallLocation.getAbsolutePath());
if (libraryInfo != null) {
- // only return endorsed and bootstrap classpath entries if we have the info
+ // only return endorsed and bootstrap loadpath entries if we have the info
// libs in the ext dirs are not loaded by the boot class loader
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|